<?php
/**
 * @file mod_roomReservationControl.inc
 * Class that represents an abstract control
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 25.07.2008
 * 
 * Copyright © 2007 Roland Hieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

require_once("quote.inc");
require_once("functions.inc");

/** @todo document */
abstract class mod_roomReservationControl {
  /** (array of strings) Errors that occur while processing the form */ 
  protected $asMessages;
  /** (mod_roomReservationConfig) Reference to the configuration object */
  protected $oCfg;
  
  /***************************************************************************/
  /**
   * @name Constructor
   * @{
   * Constructor
   * @param $oCfg (reference to mod_roomReservationConfig) Reference to the
   *  configuration
   * @return mod_roomReservationBookingTable
   */
  public function __construct(mod_roomReservationConfig &$oCfg) {
    rrAddCss(".blue .treeview .err { color:red !important; }");
    $this->oCfg = $oCfg;
    $this->processRequestVariables();
  }
 
  /***************************************************************************/
  /**
   * @}
   * @name Initialization
   * @{
   */

  /**
   * Process the REQUEST variables and preset the some variables
   * @return void
   */
  protected function processRequestVariables() { }
  
  /***************************************************************************/
  /**
   * @}
   * @name Output
   * @{
   */

  /**
   * Get the messages that have been produced. Returns HTML.
   * @return string
   */
  protected function getMessages() {
    if(count($this->asMessages) > 0) {
      return sprintf("<div class='err'>%s</p>\n",
        nl2br(q(join("\n", $this->asMessages))));
    }
  }

  /**
   * Show the beginning of the control.
   * @return void
   */
  protected function beginShow() { }
  
  /**
   * Show the control. Override this function to print your HTML code.
   * @return void
   */
  protected abstract function doShow();
  
  /**
   * Show the end of the control.
   * @return void
   */
  protected function endShow() { }

  /**
   * Show the full control. You don't need to override this function. Instead,
   * override doShow(). 
   * @return void
   */
  public function show() {
    $this->beginShow();
    $this->doShow();
    $this->endShow();
  }
}
?>