<?php
/**
 * @file mod_roomReservationRoomsManager.inc
 * Class for the management of rooms
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 28.12.2007
 * 
 * Copyright © 2007 Roland Hieber
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

require_once("db.inc");
require_once("mod_room-reservation/functions.inc");
require_once("mod_room-reservation/mod_roomReservationRoom.inc");
require_once("mod_room-reservation/mod_roomReservationConfig.inc");

db_user("roomreservation");

/** Simple class for creating, editing and deleting rooms */
class mod_roomReservationRoomsManager {
  /** (mod_roomReservationConfig) Reference to the configuration */
  protected $oCfg;
  
  /**
   * Constructor
   * @param $oCfg (reference to mod_roomReservationConfig) Reference to the
   *  configuration object
   * @return rmRoomsManager
   */
  public function __construct(mod_roomReservationConfig &$oCfg) {
    $this->oCfg = $oCfg;
  }

  /**
   * Get a room by its OID. Returns <tt>null</tt> if the room was not found.
   * @param $nOid (integer) The OID of the room
   * @return mod_roomReservationRoom
   */
  static function getRoomByOid($nOid) {
    $o = null;
    $h = db_query("SELECT * FROM rooms WHERE oid = $1;", $nOid);
    if(pg_num_rows($h) > 0) {
      $arResult = pg_fetch_array($h);
      $o = new mod_roomReservationRoom($arResult["name"], 
        $arResult["room_no"], $arResult["floor"], $arResult["building"],
        $arResult["location"]);
    }
    return $o;
  }
  
  /**
   * Get a room by its name. Returns <tt>null</tt> if the room was not found.
   * @param $sName (string) The name of the room
   * @return mod_roomReservationRoom
   */
  static function getRoomByName($sName) {
    $o = null;
    $h = db_query("SELECT * FROM rooms WHERE name = $1;", $sName);
    if(pg_num_rows($h) > 0) {
      $arResult = pg_fetch_array($h);
      $o = new mod_roomReservationRoom($arResult["name"], 
        $arResult["room_no"], $arResult["floor"], $arResult["building"],
        $arResult["location"]);
    }
    return $o;
  }
  
  /**
   * Get all rooms from the database
   * @return array of mod_roomReservationRoom
   */
  static function getRooms() {
    $aoReturn = array();
    $hQuery = db_query("SELECT * FROM rooms ORDER BY name;");
    while($arResult = pg_fetch_array($hQuery)) {
      $aoReturn[] = new mod_roomReservationRoom($arResult["name"], 
        $arResult["room_no"], $arResult["floor"], $arResult["building"],
        $arResult["location"]);
    }
    return $aoReturn;
  }
}
?>
